package com.xhpc.general.service;

import com.xhpc.common.core.web.domain.AjaxResult;
import com.xhpc.general.domain.XhpcAgreement;

import java.util.List;

/**
 * 协议管理Service接口
 * program: ruoyi
 * User: HongYun
 * Date:2021-08-03 09
 */
public interface IXhpcAgreementService {

    AjaxResult deleteAgreementItem(Long agreementId);


    AjaxResult insertAgreementItem(String title,Integer type,String content);

    AjaxResult updateAgreementItem(Long agreementId,String title,Integer type,String content);

    List<XhpcAgreement> selectAgreementItems(String title, String createBy,Integer type);

    XhpcAgreement selectAgreementItem(Long agreementId);

    XhpcAgreement selectContent(Integer type);
}
